=================
pybullet_planning
=================

.. start-badges

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :target: https://github.com/yijiangh/pybullet_planning/blob/master/LICENSE
    :alt: License MIT

.. .. image:: https://travis-ci.org/yijiangh/pybullet_planning.svg?branch=master
..     :target: https://travis-ci.org/yijiangh/pybullet_planning
..     :alt: Travis CI

.. end-badges

.. Write project description

**pybullet_planning** is a suite of utility functions to facilitate robotic planning related research on the
`pybullet <https://github.com/bulletphysics/bullet3>`_ physics simulation engine.


Main features
-------------

* feature

**pybullet_planning** runs on Python 2.5+ and 3.x.


Documentation
-------------

.. Explain how to access documentation: API, examples, etc.

..
.. optional sections:

Requirements
------------

.. Write requirements instructions here


Installation
------------

.. Write installation instructions here


Contributing
------------

Make sure you setup your local development environment correctly:

* Clone the `pybullet_planning <https://github.com/yijiangh/pybullet_planning>`_ repository.
* Install development dependencies:

::

    pip install -r requirements-dev.txt

**You're ready to start working!**

During development, use tasks on the
command line to ease recurring operations:

* ``invoke clean``: Clean all generated artifacts.
* ``invoke check``: Run various code and documentation style checks.
* ``invoke docs``: Generate documentation.
* ``invoke test``: Run all tests and checks in one swift command.
* ``invoke``: Show available tasks.

For more details, check the `Contributor's Guide <CONTRIBUTING.rst>`_.


Releasing this project
----------------------

.. Write releasing instructions here


.. end of optional sections
..

Credits
-------------

This package was initiated by Caelan Garrett <caelan@csail.mit.edu> `@caelan <https://github.com/caelan>`_,
with some maintainence from Yijiang Huang <yijiangh@mit.edu> `@yijiangh <https://github.com/yijiangh>`_.
